import PagerItem from '@opentinyvue/vue-pager-item';
import Popover from '@opentinyvue/vue-popover';
import Loading from '@opentinyvue/vue-loading';
import { t } from '@opentinyvue/vue-locale';
import { defineComponent, $props, h } from '@opentinyvue/vue-common';
import { IconChevronLeft, IconChevronRight, IconChevronDown } from '@opentinyvue/vue-icon';
import { emitEvent } from '@opentinyvue/utils';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t2 = arguments[e];
      for (var r in t2) ({}).hasOwnProperty.call(t2, r) && (n[r] = t2[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
var __vue2_script = defineComponent({
  props: _extends({}, $props, {
    accurateJumper: {
      type: Boolean,
      default: function _default() {
        return true;
      }
    },
    appendToBody: {
      type: Boolean,
      default: function _default2() {
        return true;
      }
    },
    currentPage: {
      type: Number,
      default: function _default3() {
        return 1;
      }
    },
    disabled: {
      type: Boolean,
      default: function _default4() {
        return false;
      }
    },
    hideOnSinglePage: Boolean,
    isBeforePageChange: Boolean,
    layout: String,
    mode: String,
    nextText: String,
    pageCount: Number,
    pageSize: {
      type: Number,
      default: function _default5() {
        return 10;
      }
    },
    pageSizes: {
      type: Array,
      default: function _default6() {
        return [10, 20, 30, 40, 50, 100];
      }
    },
    pagerCount: {
      type: Number,
      validator: function validator(value) {
        return (value | 0) === value && value > 2 && value < 22 && value % 2 === 1;
      },
      default: function _default7() {
        return 7;
      }
    },
    popperAppendToBody: {
      type: Boolean,
      default: function _default8() {
        return true;
      }
    },
    showTotalLoading: {
      type: Boolean,
      default: function _default9() {
        return false;
      }
    },
    customTotal: {
      type: [Boolean, String],
      default: function _default10() {
        return false;
      }
    },
    popperClass: String,
    prevText: String,
    total: Number,
    changeCompat: Boolean
  }),
  data: function data() {
    return {
      internalCurrentPage: 1,
      internalPageSize: 0,
      lastEmittedPage: -1,
      userChangePageSize: false,
      internalTotal: this.total
    };
  },
  render: function render() {
    var h2 = arguments[0];
    var layout = this.internalLayout;
    if (!layout) return null;
    if (this.hideOnSinglePage && (!this.internalPageCount || this.internalPageCount === 1)) return null;
    var TEMPLATE_MAP = {
      prev: h2("prev"),
      jumper: h2("jumper", {
        "ref": "jumper",
        "attrs": {
          "isBeforePageChange": this.isBeforePageChange,
          "max": this.internalPageCount,
          "disabled": this.disabled
        },
        "on": {
          "beforePageChange": this.beforeJumperChangeHandler
        }
      }),
      pager: h2("pager", {
        "attrs": {
          "isBeforePageChange": this.isBeforePageChange,
          "currentPage": this.internalCurrentPage,
          "pageCount": this.internalPageCount,
          "pagerCount": this.pagerCount,
          "disabled": this.disabled
        },
        "on": {
          "beforePageChange": this.beforePagerChangeHandler,
          "change": this.handleCurrentChange
        }
      }),
      next: h2("next"),
      sizes: h2("sizes", {
        "ref": "sizes",
        "attrs": {
          "isBeforePageChange": this.isBeforePageChange,
          "popperAppendToBody": this.popperAppendToBody === false ? false : this.appendToBody,
          "popperClass": this.popperClass,
          "pageSizes": this.pageSizes,
          "disabled": this.disabled
        },
        "on": {
          "beforePageChange": this.beforeSizeChangeHandler
        }
      }),
      slot: h2("slot", [typeof this.$parent.$slots.default === "function" ? this.$parent.$slots.default() : this.$parent.$slots.default]),
      total: h2("total")
    };
    var components = layout.split(",").map(function(item) {
      return item.trim();
    });
    var templateChildren = components.map(function(compo) {
      return TEMPLATE_MAP[compo];
    });
    return h2("div", {
      "class": ["text-right py-3 px-0 text-color-text-primary"]
    }, [templateChildren]);
  },
  components: {
    Prev: {
      render: function render2() {
        var h2 = arguments[0];
        var ChevronLeft = IconChevronLeft();
        return h2("button", {
          "attrs": {
            "type": "button",
            "disabled": this.$parent.disabled || this.$parent.internalCurrentPage <= 1
          },
          "class": ["group min-w-[theme(spacing.7)] h-7 text-xs py-0 px-1 text-color-text-primary bg-color-bg-1 rounded-sm outline-0 ml-0 sm:ml-2", "align-bottom cursor-pointer hover:border-color-icon-primary disabled:cursor-default"],
          "on": {
            "click": this.$parent.prev
          }
        }, [this.$parent.prevText ? h2("span", {
          "class": ["group-disabled:text-color-text-disabled group-disabled:cursor-not-allowed group-hover:text-color-icon-hover"]
        }, [this.$parent.prevText]) : h2(ChevronLeft, {
          "class": "align-sub group-disabled:fill-color-icon-disabled group-disabled:cursor-not-allowed group-hover:fill-color-icon-active"
        })]);
      }
    },
    Next: {
      render: function render3() {
        var h2 = arguments[0];
        var ChevronRight = IconChevronRight();
        return h2("button", {
          "attrs": {
            "type": "button",
            "disabled": this.$parent.disabled || this.$parent.internalCurrentPage === this.$parent.internalPageCount || this.$parent.internalPageCount === 0
          },
          "class": ["group min-w-[theme(spacing.7)] h-7 text-xs py-0 px-1 text-color-text-primary bg-color-bg-1 rounded-sm outline-0 ml-0 sm:ml-2", "align-bottom cursor-pointer hover:border-color-icon-primary disabled:cursor-default"],
          "on": {
            "click": this.$parent.next
          }
        }, [this.$parent.nextText ? h2("span", {
          "class": ["group-disabled:text-color-text-disabled group-disabled:cursor-not-allowed group-hover:text-color-icon-hover"]
        }, [this.$parent.nextText]) : h2(ChevronRight, {
          "class": "align-sub group-disabled:fill-color-icon-disabled group-disabled:cursor-not-allowed group-hover:fill-color-icon-active"
        })]);
      }
    },
    Sizes: {
      props: {
        pageSizes: Array,
        appendToBody: Boolean,
        isBeforePageChange: Boolean,
        popperClass: String,
        popperAppendToBody: {
          type: Boolean,
          default: true
        },
        disabled: Boolean
      },
      data: function data2() {
        return {
          showSizes: false
        };
      },
      watch: {
        pageSizes: {
          immediate: true,
          handler: function handler(newVal) {
            if (Array.isArray(newVal)) {
              this.$parent.internalPageSize = newVal.includes(this.$parent.pageSize) ? this.$parent.pageSize : this.pageSizes[0];
            }
          }
        },
        showSizes: function showSizes(newVal) {
          var _this = this;
          if (newVal) {
            this.$nextTick(function() {
              var width = _this.$refs.pageSize.getBoundingClientRect().width;
              var popover = document.querySelectorAll(".data-tag-pager-selector");
              Array.from(popover).forEach(function(ele) {
                ele.style.width = width + "px";
              });
            });
          }
        }
      },
      render: function render4() {
        var _this2 = this;
        var h2 = arguments[0];
        var ChevronDown = IconChevronDown();
        var scopedSlots = {
          reference: function reference() {
            return h2("div", {
              "slot": "reference",
              "class": "m-0 ml-2",
              "on": {
                "click": function click(e) {
                  return e.stopPropagation();
                }
              }
            }, [h2("div", {
              "class": ["min-w-[theme('spacing.18')] max-w-[theme('spacing.40')] relative text-left h-7 leading-7 border border-solid border-color-border ", "rounded  text-xs py-0 pr-1 pl-3 block whitespace-nowrap transition-[border] duration-300 outline-0 box-border select-none", _this2.showSizes ? "border-color-border-focus bg-color-fill-6 text-color-border-focus [&_svg]:rotate-180 [&_svg]:fill-color-brand-hover" : "", _this2.disabled ? "bg-color-border-disabled text-color-border cursor-not-allowed [&_svg]:fill-color-icon-disabled [&_svg]:cursor-not-allowed" : "bg-color-bg-1 text-color-text-primary hover:bg-color-border-disabled hover:border-color-border active:border-color-border-focus active:bg-color-fill-6 active:text-color-brand"],
              "ref": "pageSize"
            }, [h2("span", {
              "class": "text-xs mr-1 relative -top-px"
            }, [_this2.$parent.internalPageSize]), h2("span", {
              "class": "relative -top-px"
            }, [t("ui.page.page")]), h2("div", {
              "class": "w-7 h-7 leading-7 relative float-right -top-px outline-0 box-border text-center overflow-hidden cursor-pointer"
            }, [h2(ChevronDown, {
              "class": "fill-color-text-primary text-sm absolute top-0 left-0 right-0 bottom-0 m-auto hover:fill-color-icon-hover transition-transform duration-300"
            })])])]);
          },
          default: function _default11() {
            return h2("div", {
              "class": "max-h-[theme('spacing.72')] overflow-y-auto overflow-x-hidden"
            }, [h2("ul", [_this2.pageSizes.map(function(item) {
              return h2("li", {
                "class": ["min-h-[theme('spacing.8')] py-0 px-2 leading-8 max-w-full cursor-pointer overflow-hidden text-ellipsis text-center whitespace-nowrap m-1 rounded", item === _this2.$parent.internalPageSize ? "text-color-brand bg-color-fill-6" : "hover:bg-color-bg-2 text-color-text-primary"],
                "attrs": {
                  "val": item,
                  "title": item
                },
                "on": {
                  "click": function click() {
                    return _this2.handleChange(item);
                  }
                }
              }, [item]);
            })])]);
          }
        };
        return h2("div", {
          "attrs": {
            "data-tag": "tiny-pager-popover"
          },
          "class": ["hidden sm:inline-block align-middle text-xs h-7", "text-xs text-color-text-primary relative -top-px"]
        }, [h2(Popover, {
          props: {
            placement: "bottom-start",
            appendToBody: this.popperAppendToBody,
            trigger: "click",
            popperClass: "w-24 sm:p-0 sm:!mt-1 sm:!mb-1 data-tag-pager-selector" + (this.popperClass ? " " + this.popperClass : ""),
            visibleArrow: false,
            disabled: this.disabled
          },
          on: {
            show: function show() {
              _this2.showSizes = true;
            },
            hide: function hide() {
              _this2.showSizes = false;
            }
          },
          scopedSlots,
          ref: "sizesList"
        })]);
      },
      methods: {
        handleChange: function handleChange(val) {
          var _this3 = this;
          if (val !== this.$parent.internalPageSize) {
            var callback = function callback2() {
              if (!_this3.$parent.beforeChangeHandler()) {
                return false;
              }
              _this3.$parent.internalPageSize = val = parseInt(val, 10);
              _this3.$parent.userChangePageSize = true;
              _this3.showSizes = false;
              _this3.$parent.$emit("update:pageSize", val);
              _this3.$parent.$emit("size-change", val);
              _this3.$parent.$emit("page-change", {
                currentPage: _this3.$parent.internalCurrentPage,
                pageSize: val,
                total: _this3.$parent.internalTotal
              });
              _this3.$refs.sizesList.state.showPopper = false;
            };
            if (this.isBeforePageChange) {
              var newPageSize = val;
              var currentPageSize = this.$parent.internalPageSize;
              var params = {
                newPageSize,
                currentPageSize,
                callback
              };
              this.$parent.beforeSizeChangeHandler(params);
            } else {
              callback();
            }
          }
        }
      }
    },
    Jumper: {
      props: {
        isBeforePageChange: Boolean,
        disabled: Boolean,
        min: {
          type: Number,
          default: 1
        },
        max: {
          type: Number,
          default: 10
        },
        initValue: {
          type: Number,
          default: 1
        }
      },
      data: function data3() {
        return {
          backupValue: this.initValue,
          value: this.initValue
        };
      },
      watch: {
        "$parent.internalCurrentPage": {
          handler: function handler2(currentPage) {
            var value = currentPage;
            if (this.value !== value) {
              this.value = value;
            }
          },
          immediate: true
        }
      },
      methods: {
        handleFocus: function handleFocus(e) {
          this.backupValue = Number(e.target.value);
        },
        handleInput: function handleInput(e) {
          if (!e.target.value) {
            this.value = "";
          } else if (/^\d+$/.test(e.target.value)) {
            this.value = Number(e.target.value) || 1;
          }
          e.target.value = this.value;
        },
        handleChange: function handleChange2() {
          var _this4 = this;
          this.parseValueNumber();
          var callback = function callback2() {
            _this4.handleClick();
          };
          var rollback = function rollback2() {
            _this4.value = _this4.backupValue;
          };
          var newPage = this.value;
          var currentPage = this.backupValue;
          if (this.isBeforePageChange && newPage !== currentPage) {
            var params = {
              newPage,
              currentPage,
              callback,
              rollback
            };
            this.$parent.beforePagerChangeHandler(params);
          } else {
            callback();
          }
        },
        handleClick: function handleClick() {
          if (!this.$parent.canJumperGo()) return;
          this.$parent.internalCurrentPage = this.$parent.getValidCurrentPage(this.value);
          this.$parent.emitChange();
        },
        isValueNumber: function isValueNumber() {
          return !isNaN(Number(this.value));
        },
        parseValueNumber: function parseValueNumber() {
          var value = Number(String(this.value).split(/[^0-9-+.]/).join(""));
          if (isNaN(value)) {
            value = this.min;
          }
          value = Number(value.toFixed(0));
          var min = this.min;
          var max = this.max;
          if (value >= max) {
            this.value = max;
          } else if (value <= min) {
            this.value = min;
          } else {
            this.value = value;
          }
        }
      },
      render: function render5() {
        return h("div", {
          class: ["h-7 leading-7 inline-block align-middle text-xs"]
        }, [h("div", {
          class: ["text-[0] h-7"]
        }, [h("span", {
          class: ["text-xs pl-4 pr-2 text-color-text-primary"]
        }, [t("ui.page.jump")]), h("input", {
          class: ["w-8 h-7 text-center align-top rounded-sm inline-block border border-solid border-color-border hover:text-color-icon-primary hover:border-color-icon-primary", "text-color-text-primary text-xs transition-[border] duration-300 outline-0 box-border mr-0 focus:border-color-border-focus"],
          domProps: {
            value: this.value
          },
          attrs: {
            type: "tel",
            disabled: this.disabled
          },
          on: {
            focus: this.handleFocus,
            input: this.handleInput,
            change: this.handleChange
          },
          ref: "input"
        })])]);
      }
    },
    Total: {
      mounted: function mounted() {
        if (document.querySelector('[data-tag="tiny-pager-total-loading"]')) {
          Loading.service({
            target: document.querySelector('[data-tag="tiny-pager-total-loading"]')
          });
        }
      },
      render: function render6() {
        var h2 = arguments[0];
        return typeof this.$parent.internalTotal === "number" ? this.$parent.showTotalLoading ? h2("div", {
          "class": "inline-block align-middle text-xs h-7 leading-7 float-left"
        }, [h2("div", {
          "class": "h-7 leading-7 text-xs text-color-text-primary"
        }, [h2("div", {
          "attrs": {
            "data-tag": "tiny-pager-total-loading"
          },
          "class": "inline-block align-baseline h-3.5 w-3.5 mr-1.5 top-0.5 [&_[data-tag=tiny-loading-icon]]:h-3.5 [&_[data-tag=tiny-loading-icon]]:w-3.5"
        }), h2("span", {
          "class": "text-color-text-secondary"
        }, [t("ui.page.loadingTotals")])])]) : h2("div", {
          "class": "inline-block align-middle text-xs h-7 leading-7 float-left"
        }, [" ", h2("div", {
          "class": "h-7 leading-7 text-xs text-color-text-primary"
        }, [h2("span", [t("ui.page.total")]), h2("span", {
          "class": "my-0 mx-1"
        }, [this.$parent.customTotal ? this.$parent.totalText : this.$parent.internalTotal]), h2("span", [t("ui.page.item")])])]) : "";
      }
    },
    Pager: PagerItem
  },
  methods: {
    canJumperGo: function canJumperGo() {
      var inputValue = Number(this.$refs.jumper.$refs.input.value || 0);
      var currentPage = Number(this.internalCurrentPage || 0);
      return this.accurateJumper ? inputValue !== currentPage : true;
    },
    beforeSizeChangeHandler: function beforeSizeChangeHandler(params) {
      var newPageSize = params.newPageSize, currentPageSize = params.currentPageSize, callback = params.callback;
      var newPage = 1;
      var currentPage = this.internalCurrentPage;
      var temp = {
        newPage,
        newPageSize,
        currentPage,
        currentPageSize,
        callback
      };
      this.$emit("before-page-change", temp);
    },
    beforePagerChangeHandler: function beforePagerChangeHandler(params) {
      var newPage = params.newPage, currentPage = params.currentPage, callback = params.callback, rollback = params.rollback;
      var newPageSize = this.internalPageSize;
      var currentPageSize = this.internalPageSize;
      var temp = {
        newPage,
        newPageSize,
        currentPage,
        currentPageSize,
        callback,
        rollback
      };
      this.$emit("before-page-change", temp);
    },
    beforeJumperChangeHandler: function beforeJumperChangeHandler(params) {
      var newPage = params.newPage, currentPage = params.currentPage, callback = params.callback, rollback = params.rollback;
      var newPageSize = this.internalPageSize;
      var currentPageSize = this.internalPageSize;
      var temp = {
        newPage,
        newPageSize,
        currentPage,
        currentPageSize,
        callback,
        rollback
      };
      this.$emit("before-page-change", temp);
    },
    copyEmit: function copyEmit() {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }
      this.$emit.apply(this, args);
    },
    beforeChangeHandler: function beforeChangeHandler(val) {
      if (val === void 0) {
        val = -1;
      }
      return emitEvent(this.copyEmit, "before-change", this.internalCurrentPage, this, val);
    },
    handleCurrentChange: function handleCurrentChange(val) {
      if (!this.beforeChangeHandler(val)) {
        return false;
      }
      this.internalCurrentPage = this.getValidCurrentPage(val);
      this.userChangePageSize = true;
      this.emitChange();
    },
    prev: function prev() {
      var _this5 = this;
      var callback = function callback2() {
        if (_this5.disabled || !_this5.beforeChangeHandler(_this5.internalCurrentPage - 1)) {
          return false;
        }
        var newVal = _this5.internalCurrentPage - 1;
        _this5.internalCurrentPage = _this5.getValidCurrentPage(newVal);
        _this5.$emit("prev-click", _this5.internalCurrentPage);
        _this5.emitChange();
      };
      if (this.isBeforePageChange) {
        var newPage = this.internalCurrentPage - 1;
        var temp = this.buildBeforePageChangeParam({
          newPage,
          callback
        });
        this.$emit("before-page-change", temp);
      } else {
        callback();
      }
    },
    next: function next() {
      var _this6 = this;
      var callback = function callback2() {
        if (_this6.disabled || !_this6.beforeChangeHandler(_this6.internalCurrentPage + 1)) {
          return false;
        }
        var newVal = _this6.internalCurrentPage + 1;
        _this6.internalCurrentPage = _this6.getValidCurrentPage(newVal);
        _this6.$emit("next-click", _this6.internalCurrentPage);
        _this6.emitChange();
      };
      if (this.isBeforePageChange) {
        var newPage = this.internalCurrentPage + 1;
        var temp = this.buildBeforePageChangeParam({
          newPage,
          callback
        });
        this.$emit("before-page-change", temp);
      } else {
        callback();
      }
    },
    buildBeforePageChangeParam: function buildBeforePageChangeParam(param) {
      var currentPage = this.internalCurrentPage;
      var newPageSize = this.internalPageSize;
      var currentPageSize = this.internalPageSize;
      return Object.assign({
        currentPage,
        newPageSize,
        currentPageSize
      }, param);
    },
    getValidCurrentPage: function getValidCurrentPage(val) {
      val = parseInt(val, 10);
      var hasPageCount = typeof this.internalPageCount === "number";
      var resetVal;
      if (!hasPageCount) {
        if (isNaN(val) || val < 1) {
          resetVal = 1;
        }
      } else {
        if (val < 1) {
          resetVal = 1;
        } else if (val > this.internalPageCount) {
          resetVal = this.internalPageCount;
        }
      }
      if (resetVal === void 0 && isNaN(val)) {
        resetVal = 1;
      } else if (resetVal === 0) {
        resetVal = 1;
      }
      return resetVal === void 0 ? val : resetVal;
    },
    emitChange: function emitChange() {
      var _this7 = this;
      this.$nextTick(function() {
        if (_this7.internalCurrentPage !== _this7.lastEmittedPage || _this7.userChangePageSize) {
          _this7.$emit("current-change", _this7.internalCurrentPage);
          _this7.$emit("update:current-page", _this7.internalCurrentPage);
          _this7.$emit("page-change", {
            currentPage: _this7.internalCurrentPage,
            pageSize: _this7.internalPageSize,
            total: _this7.internalTotal
          });
          _this7.lastEmittedPage = _this7.internalCurrentPage;
          _this7.userChangePageSize = false;
        }
      });
    },
    setTotal: function setTotal(val) {
      this.internalTotal = val;
    }
  },
  computed: {
    totalText: function totalText() {
      if (typeof this.customTotal === "string") return this.customTotal;
      var totals = parseInt(this.total);
      if (isNaN(totals)) return 0;
      var HUNDRED_THOUSAND = 1e5;
      var MILLION = 1e6;
      var TEN_MILLION = 1e7;
      if (totals < HUNDRED_THOUSAND) {
        return totals;
      } else if (totals < MILLION) {
        return t("ui.page.hundredThousand");
      } else if (totals < TEN_MILLION) {
        return t("ui.page.million");
      } else {
        return t("ui.page.tenMillion");
      }
    },
    internalPageCount: function internalPageCount() {
      if (typeof this.internalTotal === "number") {
        return Math.max(1, Math.ceil(this.internalTotal / this.internalPageSize));
      } else if (typeof this.pageCount === "number") {
        return Math.max(1, this.pageCount);
      }
      return null;
    },
    internalLayout: function internalLayout() {
      var layout = "";
      if (this.mode && !this.layout) {
        this.mode === "number" && (layout = "sizes, prev, pager, next, jumper, total");
        this.mode === "simple" && (layout = "sizes, prev, next");
        this.mode === "complete" && (layout = "sizes, prev, pager, next, jumper,total");
        this.mode === "fixed" && (layout = "prev, pager, next");
      } else if (!this.mode && this.layout || this.mode && this.layout) {
        layout = this.layout;
      } else {
        layout = "prev, pager, next, jumper, total";
      }
      return layout;
    }
  },
  watch: {
    currentPage: {
      handler: function handler3(curPage) {
        this.internalCurrentPage = this.getValidCurrentPage(curPage);
      },
      immediate: true
    },
    internalPageCount: function internalPageCount2(pageCount) {
      var oldCurPage = this.internalCurrentPage;
      if (pageCount > 0 && oldCurPage === 0) {
        this.internalCurrentPage = 1;
      } else if (oldCurPage > pageCount) {
        this.internalCurrentPage = pageCount === 0 ? 1 : pageCount;
        this.userChangePageSize && this.emitChange();
      }
      this.userChangePageSize = false;
    },
    internalCurrentPage: {
      handler: function handler4(curPage) {
        this.$emit("update:currentPage", curPage);
        this.lastEmittedPage = -1;
      },
      immediate: true
    },
    pageSize: {
      handler: function handler5(pageSize) {
        this.internalPageSize = isNaN(pageSize) ? 10 : pageSize;
      },
      immediate: true
    },
    total: function total(_total) {
      this.internalTotal = _total;
    }
  }
});
var __vue2_render, __vue2_staticRenderFns;
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, __vue2_render, __vue2_staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
